@@ -262,13 +262,8 @@ def space(
         help="controller to use for fitness function approximation (see movado docs for more information),"
         + "'Distance' is default. 'Mab' selects a pure multi-armed bandit controller",
     ),
-    record_design_values: bool = typer.Option(
-        False, help="record all design values in a csv file"
-    ),
-    read_design_values: bool = typer.Option(
-        False,
-        help="read design values from a csv file recorded with "
-        + "the --record-design-values flag",
+    controller_mab_weight: Optional[bool] = typer.Option(
+        False, help="enable loss weighting in Distance Controller"
     ),
 ):
     """
@@ -307,10 +302,7 @@ def space(
         disable=disable_approximate,
         controller=controller_model,
         estimator=estimation_model,
-        **{
-            ctx.args[i].replace("--", ""): ctx.args[i + 1]
-            for i in range(0, len(ctx.args), 2)
-        }
+        controller_mab_weight=controller_mab_weight,
     )
 
     execution_time = optimize(
